@@ -14,7 +14,7 @@
 PORT_STATUS_ACTIVE = 'ACTIVE'
 PORT_STATUS_DOWN = 'DOWN'
 
-DEVICE_OWNER = 'kuryr:container'
+DEVICE_OWNER = 'compute:kuryr'
 NIC_NAME_LEN = 14
 VETH_PREFIX = 'tap'
 CONTAINER_VETH_PREFIX = 't_c'
